summaryrefslogtreecommitdiffstats
path: root/src/usr/local/www
diff options
context:
space:
mode:
authork-paulius <k.dash.paulius@gmail.com>2016-02-12 21:11:10 -0600
committerStephen Beaver <sbeaver@netgate.com>2016-02-13 16:38:00 -0500
commitcaf5978144f5120a1a5fbe532aba7b0739cb4148 (patch)
treef2cb08f50531cc9714e4a1a893ca0a5af5fbd8bc /src/usr/local/www
parent0f98065bb8e53af526c36e19d438239b7656b58b (diff)
downloadpfsense-caf5978144f5120a1a5fbe532aba7b0739cb4148.zip
pfsense-caf5978144f5120a1a5fbe532aba7b0739cb4148.tar.gz
Synchronize page titles with tab titles; Rename few titles in order to be more consistent.
Diffstat (limited to 'src/usr/local/www')
-rw-r--r--src/usr/local/www/vpn_ipsec_keys_edit.php2
-rw-r--r--src/usr/local/www/vpn_ipsec_phase1.php4
-rw-r--r--src/usr/local/www/vpn_ipsec_phase2.php4
-rw-r--r--src/usr/local/www/vpn_l2tp_users_edit.php2
-rw-r--r--src/usr/local/www/vpn_openvpn_client.php10
-rw-r--r--src/usr/local/www/vpn_openvpn_csc.php4
-rw-r--r--src/usr/local/www/vpn_openvpn_server.php10
7 files changed, 18 insertions, 18 deletions
diff --git a/src/usr/local/www/vpn_ipsec_keys_edit.php b/src/usr/local/www/vpn_ipsec_keys_edit.php
index 33a8faa..e9e4229 100644
--- a/src/usr/local/www/vpn_ipsec_keys_edit.php
+++ b/src/usr/local/www/vpn_ipsec_keys_edit.php
@@ -152,7 +152,7 @@ if ($_POST) {
}
}
-$pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Pre-Shared Key"), gettext("Edit"));
+$pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Pre-Shared Keys"), gettext("Edit"));
$shortcut_section = "ipsec";
include("head.inc");
diff --git a/src/usr/local/www/vpn_ipsec_phase1.php b/src/usr/local/www/vpn_ipsec_phase1.php
index 035827e..14f1ff4 100644
--- a/src/usr/local/www/vpn_ipsec_phase1.php
+++ b/src/usr/local/www/vpn_ipsec_phase1.php
@@ -651,10 +651,10 @@ function build_eal_list() {
}
if ($pconfig['mobile']) {
- $pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Mobile Client"), gettext("Edit Phase 1"));
+ $pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Mobile Clients"), gettext("Edit Phase 1"));
$editing_mobile = true;
} else {
- $pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Tunnel"), gettext("Edit Phase 1"));
+ $pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Tunnels"), gettext("Edit Phase 1"));
$editing_mobile = false;
}
diff --git a/src/usr/local/www/vpn_ipsec_phase2.php b/src/usr/local/www/vpn_ipsec_phase2.php
index 20e033e..4632e05 100644
--- a/src/usr/local/www/vpn_ipsec_phase2.php
+++ b/src/usr/local/www/vpn_ipsec_phase2.php
@@ -438,10 +438,10 @@ if ($_POST) {
}
if ($pconfig['mobile']) {
- $pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Mobile Client"), gettext("Edit Phase 2"));
+ $pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Mobile Clients"), gettext("Edit Phase 2"));
$editing_mobile = true;
} else {
- $pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Tunnel"), gettext("Edit Phase 2"));
+ $pgtitle = array(gettext("VPN"), gettext("IPsec"), gettext("Tunnels"), gettext("Edit Phase 2"));
$editing_mobile = false;
}
$shortcut_section = "ipsec";
diff --git a/src/usr/local/www/vpn_l2tp_users_edit.php b/src/usr/local/www/vpn_l2tp_users_edit.php
index a0caea6..673f088 100644
--- a/src/usr/local/www/vpn_l2tp_users_edit.php
+++ b/src/usr/local/www/vpn_l2tp_users_edit.php
@@ -60,7 +60,7 @@
##|*MATCH=vpn_l2tp_users_edit.php*
##|-PRIV
-$pgtitle = array(gettext("VPN"), gettext("L2TP"), gettext("User"), gettext("Edit"));
+$pgtitle = array(gettext("VPN"), gettext("L2TP"), gettext("Users"), gettext("Edit"));
$shortcut_section = "l2tps";
function l2tpusercmp($a, $b) {
diff --git a/src/usr/local/www/vpn_openvpn_csc.php b/src/usr/local/www/vpn_openvpn_csc.php
index 10d7ade..9df3510 100644
--- a/src/usr/local/www/vpn_openvpn_csc.php
+++ b/src/usr/local/www/vpn_openvpn_csc.php
@@ -319,8 +319,8 @@ if ($savemsg) {
}
$tab_array = array();
-$tab_array[] = array(gettext("Server"), false, "vpn_openvpn_server.php");
-$tab_array[] = array(gettext("Client"), false, "vpn_openvpn_client.php");
+$tab_array[] = array(gettext("Servers"), false, "vpn_openvpn_server.php");
+$tab_array[] = array(gettext("Clients"), false, "vpn_openvpn_client.php");
$tab_array[] = array(gettext("Client Specific Overrides"), true, "vpn_openvpn_csc.php");
$tab_array[] = array(gettext("Wizards"), false, "wizard.php?xml=openvpn_wizard.xml");
add_package_tabs("OpenVPN", $tab_array);
diff --git a/src/usr/local/www/vpn_openvpn_client.php b/src/usr/local/www/vpn_openvpn_client.php
index 3b9ae7e..bc60d6c 100644
--- a/src/usr/local/www/vpn_openvpn_client.php
+++ b/src/usr/local/www/vpn_openvpn_client.php
@@ -56,8 +56,8 @@
##|+PRIV
##|*IDENT=page-openvpn-client
##|*NAME=OpenVPN: Client
##|*DESCR=Allow access to the 'OpenVPN: Client' page.
##|*MATCH=vpn_openvpn_client.php*
##|-PRIV
@@ -67,7 +67,7 @@ require_once("pkg-utils.inc");
global $openvpn_topologies;
-$pgtitle = array(gettext("VPN"), gettext("OpenVPN"), gettext("Client"));
+$pgtitle = array(gettext("VPN"), gettext("OpenVPN"), gettext("Clients"));
$shortcut_section = "openvpn";
if (!is_array($config['openvpn']['openvpn-client'])) {
@@ -441,8 +441,8 @@ if ($savemsg) {
}
$tab_array = array();
-$tab_array[] = array(gettext("Server"), false, "vpn_openvpn_server.php");
-$tab_array[] = array(gettext("Client"), true, "vpn_openvpn_client.php");
+$tab_array[] = array(gettext("Servers"), false, "vpn_openvpn_server.php");
+$tab_array[] = array(gettext("Clients"), true, "vpn_openvpn_client.php");
$tab_array[] = array(gettext("Client Specific Overrides"), false, "vpn_openvpn_csc.php");
$tab_array[] = array(gettext("Wizards"), false, "wizard.php?xml=openvpn_wizard.xml");
add_package_tabs("OpenVPN", $tab_array);
@@ -56,8 +56,8 @@
##|+PRIV
##|*IDENT=page-openvpn-client
-##|*NAME=OpenVPN: Client
-##|*DESCR=Allow access to the 'OpenVPN: Client' page.
+##|*NAME=OpenVPN: Clients
+##|*DESCR=Allow access to the 'OpenVPN: Clients' page.
##|*MATCH=vpn_openvpn_client.php*
##|-PRIV
diff --git a/src/usr/local/www/vpn_openvpn_server.php b/src/usr/local/www/vpn_openvpn_server.php
index da65de9..23731d1 100644
--- a/src/usr/local/www/vpn_openvpn_server.php
+++ b/src/usr/local/www/vpn_openvpn_server.php
@@ -56,8 +56,8 @@
##|+PRIV
##|*IDENT=page-openvpn-server
##|*NAME=OpenVPN: Server
##|*DESCR=Allow access to the 'OpenVPN: Server' page.
##|*MATCH=vpn_openvpn_server.php*
##|-PRIV
@@ -589,7 +589,7 @@ if ($_POST) {
}
}
-$pgtitle = array(gettext("VPN"), gettext("OpenVPN"), gettext("Server"));
+$pgtitle = array(gettext("VPN"), gettext("OpenVPN"), gettext("Servers"));
$shortcut_section = "openvpn";
include("head.inc");
@@ -607,8 +607,8 @@ if ($savemsg) {
}
$tab_array = array();
-$tab_array[] = array(gettext("Server"), true, "vpn_openvpn_server.php");
-$tab_array[] = array(gettext("Client"), false, "vpn_openvpn_client.php");
+$tab_array[] = array(gettext("Servers"), true, "vpn_openvpn_server.php");
+$tab_array[] = array(gettext("Clients"), false, "vpn_openvpn_client.php");
$tab_array[] = array(gettext("Client Specific Overrides"), false, "vpn_openvpn_csc.php");
$tab_array[] = array(gettext("Wizards"), false, "wizard.php?xml=openvpn_wizard.xml");
add_package_tabs("OpenVPN", $tab_array);
@@ -56,8 +56,8 @@
##|+PRIV
##|*IDENT=page-openvpn-server
-##|*NAME=OpenVPN: Server
-##|*DESCR=Allow access to the 'OpenVPN: Server' page.
+##|*NAME=OpenVPN: Servers
+##|*DESCR=Allow access to the 'OpenVPN: Servers' page.
##|*MATCH=vpn_openvpn_server.php*
##|-PRIV
OpenPOWER on IntegriCloud